aboutsummaryrefslogtreecommitdiff
path: root/ML_WaveToyFO
diff options
context:
space:
mode:
authorErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
committerErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
commitd178c81a0cb1da927bfd7d0bb64043d9484b353b (patch)
tree2a48ab29ef4a72dc1d1ae60e00cd7c0f231ae823 /ML_WaveToyFO
parent87fa6dcf3ff19d937313d20cca8f9e2bca1d4aec (diff)
Allow 4 RHS time levels.
Re-generate code.
Diffstat (limited to 'ML_WaveToyFO')
-rw-r--r--ML_WaveToyFO/schedule.ccl6
-rw-r--r--ML_WaveToyFO/src/Boundaries.c34
2 files changed, 20 insertions, 20 deletions
diff --git a/ML_WaveToyFO/schedule.ccl b/ML_WaveToyFO/schedule.ccl
index 4aea873..5f30943 100644
--- a/ML_WaveToyFO/schedule.ccl
+++ b/ML_WaveToyFO/schedule.ccl
@@ -99,14 +99,14 @@ schedule WTFO_constraints AT analysis
SYNC: WT_w
} "WTFO_constraints"
-schedule ML_WaveToyFO_ApplyBoundConds in MoL_PostStep
+schedule ML_WaveToyFO_SelectBoundConds in MoL_PostStep
{
LANG: C
OPTIONS: level
SYNC: WT_rho
SYNC: WT_u
SYNC: WT_v
-} "apply boundary conditions"
+} "select boundary conditions"
schedule ML_WaveToyFO_CheckBoundaries at BASEGRID
{
@@ -114,7 +114,7 @@ schedule ML_WaveToyFO_CheckBoundaries at BASEGRID
OPTIONS: meta
} "check boundaries treatment"
-schedule group ApplyBCs as ML_WaveToyFO_ApplyBCs in MoL_PostStep after ML_WaveToyFO_ApplyBoundConds
+schedule group ApplyBCs as ML_WaveToyFO_ApplyBCs in MoL_PostStep after ML_WaveToyFO_SelectBoundConds
{
# no language specified
} "Apply boundary conditions controlled by thorn Boundary"
diff --git a/ML_WaveToyFO/src/Boundaries.c b/ML_WaveToyFO/src/Boundaries.c
index 6c25491..4f5f933 100644
--- a/ML_WaveToyFO/src/Boundaries.c
+++ b/ML_WaveToyFO/src/Boundaries.c
@@ -25,7 +25,7 @@ void ML_WaveToyFO_CheckBoundaries(CCTK_ARGUMENTS)
return;
}
-void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
+void ML_WaveToyFO_SelectBoundConds(CCTK_ARGUMENTS)
{
DECLARE_CCTK_ARGUMENTS;
DECLARE_CCTK_PARAMETERS;
@@ -122,7 +122,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -141,7 +141,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -160,7 +160,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_v_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_WT_v_bound = -1;
if (handle_WT_v_bound < 0) handle_WT_v_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_v_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -179,7 +179,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -198,7 +198,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -217,7 +217,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v1_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_v1_bound = -1;
if (handle_v1_bound < 0) handle_v1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -236,7 +236,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v2_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_v2_bound = -1;
if (handle_v2_bound < 0) handle_v2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -255,7 +255,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v3_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_v3_bound = -1;
if (handle_v3_bound < 0) handle_v3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -274,7 +274,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -291,7 +291,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -308,7 +308,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_v_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_WT_v_bound = -1;
if (handle_WT_v_bound < 0) handle_WT_v_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_v_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -325,7 +325,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -342,7 +342,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -359,7 +359,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v1_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_v1_bound = -1;
if (handle_v1_bound < 0) handle_v1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -376,7 +376,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v2_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_v2_bound = -1;
if (handle_v2_bound < 0) handle_v2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -393,7 +393,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v3_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_v3_bound = -1;
if (handle_v3_bound < 0) handle_v3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_v3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -122,7 +122,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -141,7 +141,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -160,7 +160,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_v_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_WT_v_bound = -1;
if (handle_WT_v_bound < 0) handle_WT_v_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -179,7 +179,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -198,7 +198,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -217,7 +217,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v1_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_v1_bound = -1;
if (handle_v1_bound < 0) handle_v1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -236,7 +236,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v2_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_v2_bound = -1;
if (handle_v2_bound < 0) handle_v2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -255,7 +255,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v3_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_v3_bound = -1;
if (handle_v3_bound < 0) handle_v3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -274,7 +274,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -291,7 +291,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -308,7 +308,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_v_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_WT_v_bound = -1;
if (handle_WT_v_bound < 0) handle_WT_v_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -325,7 +325,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -342,7 +342,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -359,7 +359,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v1_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_v1_bound = -1;
if (handle_v1_bound < 0) handle_v1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -376,7 +376,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v2_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_v2_bound = -1;
if (handle_v2_bound < 0) handle_v2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -393,7 +393,7 @@ void ML_WaveToyFO_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(v3_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_v3_bound = -1;
if (handle_v3_bound < 0) handle_v3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);